@@ -3,7 +3,7 @@
 #
 # This file is part of LilyPond, the GNU music typesetter.
 #
-# Copyright (C) 2010--2020 Reinhold Kainhofer <reinhold@kainhofer.com>
+# Copyright (C) 2010--2022 Reinhold Kainhofer <reinhold@kainhofer.com>
 #
 # LilyPond is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,6 @@
 # along with LilyPond.  If not, see <http://www.gnu.org/licenses/>.
 
 
-import codecs
 import copy
 import hashlib
 import os
@@ -31,10 +30,6 @@ import sys
 import book_base
 import lilylib as ly
 
-progress = ly.progress
-warning = ly.warning
-error = ly.error
-debug = ly.debug_output
 
 
 ####################################################################
@@ -60,13 +55,17 @@ NOFRAGMENT = 'nofragment'
 NOGETTEXT = 'nogettext'
 NOINDENT = 'noindent'
 INDENT = 'indent'
+INLINE = 'inline'
 NORAGGED_RIGHT = 'noragged-right'
 NOTES = 'body'
 NOTIME = 'notime'
 OUTPUT = 'output'
 OUTPUTIMAGE = 'outputimage'
 PAPER = 'paper'
+PAPER_HEIGHT = 'paper-height'
 PAPERSIZE = 'papersize'
+PAPER_WIDTH = 'paper-width'
+PARA = 'para'
 PREAMBLE = 'preamble'
 PRINTFILENAME = 'printfilename'
 QUOTE = 'quote'
@@ -96,9 +95,12 @@ PROCESSING_INDEPENDENT_OPTIONS = (
 simple_options = [
     EXAMPLEINDENT,
     FRAGMENT,
+    INLINE,
     NOFRAGMENT,
     NOGETTEXT,
     NOINDENT,
+    PAPER_HEIGHT,
+    PAPER_WIDTH,
     PRINTFILENAME,
     DOCTITLE,
     TEXIDOC,
@@ -122,7 +124,7 @@ snippet_options = {
     # TODO: Remove the 1mm additional padding in the line-width
     #       once lilypond creates tighter cropped images!
     PAPER: {
-        PAPERSIZE: r'''#(set-paper-size "%(papersize)s")''',
+        PAPERSIZE: r'''#(set-paper-size %(papersize)s)''',
         INDENT: r'''indent = %(indent)s''',
         LINE_WIDTH: r'''line-width = %(line-width)s
   %% offset the left padding, also add 1mm as lilypond creates cropped
@@ -145,7 +147,7 @@ snippet_options = {
  }
  \context {
    \Staff
-   \remove "Time_signature_engraver"
+   \remove Time_signature_engraver
  }''',
     },
 
@@ -171,7 +173,7 @@ def classic_lilypond_book_compatibility(key, value):
         return ('staffsize', m.group(1))
 
     if key == 'indent' or key == 'line-width':
-        m = re.match('([-.0-9]+)(cm|in|mm|pt|staffspace)', value)
+        m = re.match('([-.0-9]+)(cm|in|mm|pt|bp|staffspace)', value)
         if m:
             f = float(m.group(1))
             return (key, '%f\\%s' % (f, m.group(2)))
@@ -188,6 +190,8 @@ PREAMBLE_LY = r'''%%%% Generated by lilypond-book
 %% Start cut-&-pastable-section
 %% ****************************************************************
 
+%(padding_mm_string)s
+
 %(preamble_string)s
 
 \paper {
@@ -198,7 +202,6 @@ PREAMBLE_LY = r'''%%%% Generated by lilypond-book
   %(layout_string)s
 }
 
-%(safe_mode_string)s
 '''
 
 
@@ -251,6 +254,7 @@ ly_var_def_re = re.compile(r'^([a-zA-Z]+)[\t ]*=', re.M)
 ly_comment_re = re.compile(r'(%+[\t ]*)(.*)$', re.M)
 ly_context_id_re = re.compile('\\\\(?:new|context)\\s+(?:[a-zA-Z]*?(?:Staff\
 (?:Group)?|Voice|FiguredBass|FretBoards|Names|Devnull))\\s+=\\s+"?([a-zA-Z]+)"?\\s+')
+ly_dimen_re = re.compile(r'^([0-9]+\.?[0-9]*|\.[0-9]+)\s*\\(cm|mm|in|pt|bp)$')
 
 
 def ly_comment_gettext(t, m):
@@ -276,17 +280,11 @@ class Chunk:
         return False
 
     def __init__(self):
-        self._input_fullpath = ''
         self._output_fullpath = ''
 
-    def set_document_fullpaths(self, in_fp: str, out_fp: str):
-        self._input_fullpath = in_fp
+    def set_output_fullpath(self, out_fp: str):
         self._output_fullpath = out_fp
 
-    def input_fullpath(self) -> str:
-        """The input file path where this chunk comes from."""
-        return self._input_fullpath
-
     def output_fullpath(self) -> str:
         """The output file path that this chunk belongs to."""
         return self._output_fullpath
@@ -432,20 +430,58 @@ class LilypondSnippet (Snippet):
             (c_key, c_value) = classic_lilypond_book_compatibility(key, value)
             if c_key:
                 if c_value:
-                    warning(
+                    ly.warning(
                         _("deprecated ly-option used: %s=%s") % (key, value))
-                    warning(
+                    ly.warning(
                         _("compatibility mode translation: %s=%s") % (c_key, c_value))
                 else:
-                    warning(
+                    ly.warning(
                         _("deprecated ly-option used: %s") % key)
-                    warning(
+                    ly.warning(
                         _("compatibility mode translation: %s") % c_key)
                 (key, value) = (c_key, c_value)
             # Finally, insert the option:
             if key:
                 self.snippet_option_dict[key] = value
 
+        if PAPERSIZE in self.snippet_option_dict:
+            self.snippet_option_dict[PAPERSIZE] = (
+                '"' + self.snippet_option_dict[PAPERSIZE] + '"')
+
+        # If we have an explicit paper width or height, use it,
+        # overriding a `papersize` option.  If either width or height
+        # is missing, use the corresponding A4 dimension.
+        has_paper_width = PAPER_WIDTH in self.snippet_option_dict
+        has_paper_height = PAPER_HEIGHT in self.snippet_option_dict
+        if has_paper_width or has_paper_height:
+            if not has_paper_height:
+                self.snippet_option_dict[PAPER_HEIGHT] = r'297\mm'
+            if not has_paper_width:
+                self.snippet_option_dict[PAPER_WIDTH] = r'210\mm'
+
+            wd = self.snippet_option_dict[PAPER_WIDTH]
+            m = re.match(ly_dimen_re, wd)
+            if m:
+                (w, w_unit) = m.group(1, 2)
+            else:
+                ly.warning(_("ignoring invalid option %s=%s")
+                    % (PAPER_WIDTH, wd))
+                # Use A4 paper width in case of error
+                (w, w_unit) = ("210", "mm")
+
+            ht = self.snippet_option_dict[PAPER_HEIGHT]
+            m = re.match(ly_dimen_re, ht)
+            if m:
+                (h, h_unit) = m.group(1, 2)
+            else:
+                ly.warning(_("ignoring invalid option %s=%s")
+                    % (PAPER_HEIGHT, ht))
+                # Use A4 paper height in case of error
+                (h, h_unit) = ("297", "mm")
+
+            self.snippet_option_dict[PAPERSIZE] = (
+              "'(cons (* %s %s) (* %s %s))" % (w, w_unit, h, h_unit))
+
         # If LINE_WIDTH is used without parameter, set it to default.
         has_line_width = LINE_WIDTH in self.snippet_option_dict
         if has_line_width and self.snippet_option_dict[LINE_WIDTH] is None:
@@ -465,8 +501,8 @@ class LilypondSnippet (Snippet):
 
         # also construct a list of all options (as strings) that influence the
         # visual appearance of the snippet
-        lst = [x_y for x_y in iter(self.option_dict.items(
-        )) if x_y[0] not in PROCESSING_INDEPENDENT_OPTIONS]
+        lst = [x_y for x_y in iter(self.option_dict.items())
+                     if x_y[0] not in PROCESSING_INDEPENDENT_OPTIONS]
         option_list = []
         for (key, value) in lst:
             if value is None:
@@ -482,10 +518,11 @@ class LilypondSnippet (Snippet):
         # #(define line-width (- line-width (* 3 mm)))
         # TODO: Junk this ugly hack if the code gets rewritten to concatenate
         # all settings before writing them in the \paper block.
+        #
         # if not LINE_WIDTH in self.option_dict:
-        # if not QUOTE in self.option_dict:
-        # self.option_dict[LINE_WIDTH] = "#(- paper-width \
-# left-margin-default right-margin-default)"
+        #     if not QUOTE in self.option_dict:
+        #         self.option_dict[LINE_WIDTH] = \
+        #           "#(- paper-width left-margin-default right-margin-default)"
 
     # Get a list of all options (as string) that influence the snippet appearance
 
@@ -556,7 +593,7 @@ class LilypondSnippet (Snippet):
                     break
 
             if not found and key not in simple_options and key not in self.snippet_options():
-                warning(_("ignoring unknown ly option: %s") % key)
+                ly.warning(_("ignoring unknown ly option: %s") % key)
 
         # URGS
         if RELATIVE in override and override[RELATIVE]:
@@ -570,6 +607,14 @@ class LilypondSnippet (Snippet):
         elif relative > 0:
             relative_quotes += "'" * relative
 
+        if INLINE in override:
+            # For inline images, try to make left and right padding equal,
+            # ignoring the `--left-padding` value.
+            #
+            # URGH Value 0 makes LilyPond apply no left padding at all, but
+            #      still having some right padding.  This is a bug (#6116).
+            override['padding_mm'] = 0.0001
+
         # put paper-size first, if it exists
         for i, elem in enumerate(compose_dict[PAPER]):
             if elem.startswith("#(set-paper-size"):
@@ -580,11 +625,13 @@ class LilypondSnippet (Snippet):
         layout_string = '\n  '.join(compose_dict[LAYOUT]) % override
         notes_string = '\n  '.join(compose_dict[NOTES]) % vars()
         preamble_string = '\n  '.join(compose_dict[PREAMBLE]) % override
-        padding_mm = self.global_options.padding_mm
-        if self.global_options.safe_mode:
-            safe_mode_string = "#(ly:set-option 'safe #t)"
+
+        padding_mm = override['padding_mm']
+        if padding_mm != 0:
+            padding_mm_string = \
+                "#(ly:set-option 'eps-box-padding %f)" % padding_mm
         else:
-            safe_mode_string = ""
+            padding_mm_string = ""
 
         d = globals().copy()
         d.update(locals())
@@ -624,17 +671,17 @@ class LilypondSnippet (Snippet):
         os.makedirs(directory, exist_ok=True)
         filename = path + '.ly'
         if os.path.exists(filename):
-            existing = codecs.open(filename, 'r', 'utf-8').read()
+            existing = open(filename, 'r', encoding='utf-8').read()
 
             if self.relevant_contents(existing) != self.relevant_contents(self.full_ly()):
-                warning("%s: duplicate filename but different contents of original file,\n\
+                ly.warning("%s: duplicate filename but different contents of original file,\n\
 printing diff against existing file." % filename)
                 encoded = self.full_ly().encode('utf-8')
                 cmd = 'diff -u %s -' % filename
                 sys.stderr.write(self.filter_pipe(
                     encoded, cmd).decode('utf-8'))
         else:
-            out = codecs.open(filename, 'w', 'utf-8')
+            out = open(filename, 'w', encoding='utf-8')
             out.write(self.full_ly())
 
     def relevant_contents(self, ly):
@@ -643,7 +690,7 @@ printing diff against existing file." % filename)
     def link_all_output_files(self, output_dir, destination):
         existing, missing = self.all_output_files(output_dir)
         if missing:
-            error(_('Missing files: %s') % ', '.join(missing))
+            ly.error(_('Missing files: %s') % ', '.join(missing))
             raise CompileError(self.basename())
         for name in existing:
             if (self.global_options.use_source_file_names
@@ -681,7 +728,7 @@ printing diff against existing file." % filename)
                     except AttributeError:
                         shutil.copyfile(src, dst)
             except (IOError, OSError):
-                error(_('Could not overwrite file %s') % dst)
+                ly.error(_('Could not overwrite file %s') % dst)
                 raise CompileError(self.basename())
 
     def additional_files_to_consider(self, base, full):
@@ -750,11 +797,7 @@ printing diff against existing file." % filename)
             systemfile = '%s-%d' % (base, number)
             require_file(systemfile + '.eps')
             consider_file(systemfile + '.pdf')
-
-            # We can't require signatures, since books and toplevel
-            # markups do not output a signature.
-            if 'ddump-signature' in self.global_options.process_cmd:
-                consider_file(systemfile + '.signature')
+            consider_file(systemfile + '.png')
 
         for f in  self.additional_files_to_consider(base, full):
             consider_file(f)
@@ -778,7 +821,7 @@ printing diff against existing file." % filename)
         Returns:
           the filtered result
         """
-        debug(_("Running through filter `%s'") % cmd, True)
+        ly.debug_output(_("Running through filter `%s'") % cmd, True)
 
         closefds = True
         if sys.platform == "mingw32":
@@ -804,11 +847,11 @@ printing diff against existing file." % filename)
         if status or (not output and err):
             exit_status = status >> 8
             ly.error(_("`%s' failed (%d)") % (cmd, exit_status))
-            ly.error(_("The error log is as follows:"))
+            ly.error(_("The ly.error log is as follows:"))
             sys.stderr.write(err)
             exit(status)
 
-        debug('\n')
+        ly.debug_output('\n')
 
         return output
 
@@ -866,8 +909,9 @@ class LilypondFileSnippet (LilypondSnippet):
 
     def get_contents(self) -> bytes:
         if not self.contents:
-            self.contents = open(book_base.find_file(self.filename,
-                                                     self.global_options.include_path, self.global_options.original_dir), 'rb').read()
+            path = book_base.find_file(self.filename,
+                self.global_options.include_path)
+            self.contents = open(path, 'rb').read()
         return self.contents
 
     def get_snippet_code(self) -> str:
@@ -934,7 +978,7 @@ class MusicXMLFileSnippet (LilypondFileSnippet):
             xml2ly_option_list.append('--compressed')
             self.compressed = True
         opts = " ".join(xml2ly_option_list)
-        progress(_("Converting MusicXML file `%s'...") % self.filename)
+        ly.progress(_("Converting MusicXML file `%s'...") % self.filename)
 
         cmd = 'musicxml2ly %s --out=- - ' % opts
         ly_code = self.filter_pipe(self.get_contents(), cmd).decode('utf-8')
@@ -962,7 +1006,7 @@ class MusicXMLFileSnippet (LilypondFileSnippet):
             diff_against_existing = self.filter_pipe(
                 self.get_contents(), 'diff -u %s - ' % xmlfilename)
             if diff_against_existing:
-                warning(_("%s: duplicate filename but different contents of original file,\n\
+                ly.warning(_("%s: duplicate filename but different contents of original file,\n\
 printing diff against existing file.") % xmlfilename)
                 sys.stderr.write(diff_against_existing.decode('utf-8'))
         else:
@@ -978,11 +1022,11 @@ printing diff against existing file.") % xmlfilename)
             diff_against_existing = self.filter_pipe(
                 encoded, cmd).decode('utf-8')
             if diff_against_existing:
-                warning(_("%s: duplicate filename but different contents of converted lilypond file,\n\
+                ly.warning(_("%s: duplicate filename but different contents of converted lilypond file,\n\
 printing diff against existing file.") % filename)
                 sys.stderr.write(diff_against_existing.decode('utf-8'))
         else:
-            out = codecs.open(filename, 'w', 'utf-8')
+            out = open(filename, 'w', encoding='utf-8')
             out.write(self.full_ly())
             out.close()
 
